<?php

    class File_Age_Condition extends Reactor_Condition
    {
        protected $tpl = 'file_age.php';
        protected $name = 'File age is';
		
		public static $registration = array(
			CONDITION_NAME => 'File age',
			CONDITION_CATEGORY => 'Local',
			CONDITION_DESCRIPTION => 'Compares the age of a file against a threshold',
			CONDITION_AUTHOR => 'Mike Guthrie, Nagios Enterprises, LLC',
			CONDITION_VERSION => '1.0',
			CONDITION_DATE => '01/26/2013', //Last version update
			CONDITION_AUTHLEVEL => 0,  // 0 - everyone | 1 - Admin only
			CONDITION_TYPE => 'core', //core | user. core modules can't be deleted
			CONDITION_META => array('mtime'),	//Misc information	
		); 			
		
        protected $fields = array(
            'filename' => array(
                'label' => 'filename',
                'validate' => 'trim|required|xss_clean',
            ),
            'oldernewer' => array(
                'label' => 'oldernewer',
                'validate' => 'xss_clean',
            ),	
            'number' => array(
                'label' => 'number',
                'validate' => 'xss_clean|numeric',
            ),	
            'units' => array(
                'label' => 'units',
                'validate' => 'xss_clean',
            ),			
        );

        public function get_label()
        {
            $params = $this->get_params();
			$str=implode(' ',$params);
			//return sprintf('File Age Condition. Params: %s ', $str);
			
			$file = $params['filename'];
			$oldernewer = $params['oldernewer']; 
			$number = $params['number'];
			$units = $params['units']; 
			
			$cstr=$oldernewer;
			
			return sprintf('File \'%s\' is %s than %s %s',$file,$cstr,$number,$units);

        }
       
        public function run($context)
        {
			
			if(ENVIRONMENT=='development')
				logit("Running file_age condition...");
								
            $this->set_context($context);
            $params = $this->get_params();
			
			$file = $params['filename'];
			$oldernewer = $params['oldernewer']; 
			$number = $params['number'];
			$units = $params['units']; 

			//sanity
			if(!file_exists($file)) {
				if(ENVIRONMENT=='development')
					logit("File does not exist: {$file}");
				$this->set_result(false);
				return;
			}
			$mtime = filemtime($file);
			
			//testing method to save context vars with conditions
			$this->set_context_var('mtime', $mtime);
				
			//what time unit should we use
			switch($units) {
				case 'days':
					$mult=60*60*24; 
				break; 
				
				case 'hours':
					$mult = 60*60;
				break;
				
				case 'minutes':
					$mult = 60; 
				break;
			
				case 'seconds':
				default:	
					$mult = 1;
				break; 
			
			}
			
			$now = time(); 
			$threshold = $now - ($number * $mult);
			
			if($oldernewer=='newer')
            	$this->set_result($mtime > $threshold);
			else  //older than
            	$this->set_result($mtime < $threshold); 
				
			if(ENVIRONMENT=='development')
				logit("FILE AGE: mtime={$mtime}, threshold={$threshold}, mult={$mult}"); 
			
			return $context;
        }
    }
